==> haskell-bytestring-handle-0.1.0.6-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-handle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-handle
version:              0.1.0.6
visibility:           public
id:                   bytestring-handle-0.1.0.6-2ZLW90kZ7rj4f7EltJHRd6
key:                  bytestring-handle-0.1.0.6-2ZLW90kZ7rj4f7EltJHRd6
license:              BSD-3-Clause
maintainer:           Ganesh Sittampalam <ganesh@earth.li>
author:               Ganesh Sittampalam
homepage:             http://hub.darcs.net/ganesh/bytestring-handle
synopsis:             ByteString-backed Handles
category:             System
abi:                  c48d05ec44f519b01362e285bcb3115e
exposed:              True
exposed-modules:      Data.ByteString.Handle
hidden-modules:
    Data.ByteString.Handle.Read Data.ByteString.Handle.Write

import-dirs:          /usr/lib/ghc-9.0.1/site-local/bytestring-handle-0.1.0.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/bytestring-handle-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/bytestring-handle-0.1.0.6
hs-libraries:         HSbytestring-handle-0.1.0.6-2ZLW90kZ7rj4f7EltJHRd6
depends:              base-4.15.0.0 bytestring-0.10.12.1
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-handle/html/bytestring-handle.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-handle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-handle-0.1.0.6-72-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-handle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-handle
version:              0.1.0.6
visibility:           public
id:                   bytestring-handle-0.1.0.6-3IeFX8ZtZFgFWRPvTZGa5w
key:                  bytestring-handle-0.1.0.6-3IeFX8ZtZFgFWRPvTZGa5w
license:              BSD-3-Clause
maintainer:           Ganesh Sittampalam <ganesh@earth.li>
author:               Ganesh Sittampalam
homepage:             http://hub.darcs.net/ganesh/bytestring-handle
synopsis:             ByteString-backed Handles
category:             System
abi:                  550c90cd3665dc3ca724a56ace6264f0
exposed:              True
exposed-modules:      Data.ByteString.Handle
hidden-modules:
    Data.ByteString.Handle.Read Data.ByteString.Handle.Write

import-dirs:          /usr/lib/ghc-9.0.1/site-local/bytestring-handle-0.1.0.6
library-dirs:         /usr/lib/ghc-9.0.1/site-local/bytestring-handle-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/bytestring-handle-0.1.0.6
hs-libraries:         HSbytestring-handle-0.1.0.6-3IeFX8ZtZFgFWRPvTZGa5w
depends:              base-4.15.0.0 bytestring-0.10.12.1
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-handle/html/bytestring-handle.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-handle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
